summaryrefslogtreecommitdiff
path: root/gpsd.h
diff options
context:
space:
mode:
authorGary E. Miller <gem@rellim.com>2019-04-13 20:22:36 -0700
committerGary E. Miller <gem@rellim.com>2019-04-13 20:22:36 -0700
commitb9d90b0d616ad7123d2e3d855c86dd4f500fdab8 (patch)
treefae3de484a896b5b96116fd012ce896e1a60c36f /gpsd.h
parentf96ba69fecf003dbcd7e76018303c984df949de0 (diff)
downloadgpsd-b9d90b0d616ad7123d2e3d855c86dd4f500fdab8.tar.gz
driver_ubx: Working cycle end detection.
This should force output when people program their u-blox in strange ways. The obvious effect on the regressions is just extra TPV output. Need to improve the cycle detection a bit more to prevent that.
Diffstat (limited to 'gpsd.h')
-rw-r--r--gpsd.h7
1 files changed, 4 insertions, 3 deletions
diff --git a/gpsd.h b/gpsd.h
index fcff9f6c..c3322475 100644
--- a/gpsd.h
+++ b/gpsd.h
@@ -58,7 +58,7 @@ extern "C" {
* Add cfg_stage and cfg_step, for initialization
* Add oldfix2 for better oldfix
* Make subtype longer
- * Add ubx.protver, ubx.end_class and more to gps_device_t.ubx
+ * Add ubx.protver, ubx.last_msgid and more to gps_device_t.ubx
*/
/* Keep in sync with api_major_version and api_minor gps/__init__.py */
#define GPSD_PROTO_MAJOR_VERSION 3 /* bump on incompatible changes */
@@ -701,8 +701,9 @@ struct gps_device_t {
unsigned char port_id;
unsigned char sbas_in_use;
unsigned char protver; /* u-blox protocol version */
- unsigned char last_msgid; /* last class/ID */
- unsigned char end_msgid; /* cycle ender class/ID */
+ unsigned int last_msgid; /* last class/ID */
+ timestamp_t last_time; /* time of last_msgid */
+ unsigned int end_msgid; /* cycle ender class/ID */
} ubx;
#endif /* UBLOX_ENABLE */
#ifdef NAVCOM_ENABLE